==> opensearch-dashboards-2.15.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/data/server/index_patterns/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  IndexPatternsFetcher: true,
  FieldDescriptor: true,
  shouldReadFieldFromDocValues: true,
  IndexPatternsService: true,
  IndexPatternsServiceStart: true,
  decideClient: true
};
Object.defineProperty(exports, "FieldDescriptor", {
  enumerable: true,
  get: function () {
    return _fetcher.FieldDescriptor;
  }
});
Object.defineProperty(exports, "IndexPatternsFetcher", {
  enumerable: true,
  get: function () {
    return _fetcher.IndexPatternsFetcher;
  }
});
Object.defineProperty(exports, "IndexPatternsService", {
  enumerable: true,
  get: function () {
    return _index_patterns_service.IndexPatternsService;
  }
});
Object.defineProperty(exports, "IndexPatternsServiceStart", {
  enumerable: true,
  get: function () {
    return _index_patterns_service.IndexPatternsServiceStart;
  }
});
Object.defineProperty(exports, "decideClient", {
  enumerable: true,
  get: function () {
    return _routes.decideClient;
  }
});
Object.defineProperty(exports, "shouldReadFieldFromDocValues", {
  enumerable: true,
  get: function () {
    return _fetcher.shouldReadFieldFromDocValues;
  }
});
var _utils = require("./utils");
Object.keys(_utils).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _utils[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _utils[key];
    }
  });
});
var _fetcher = require("./fetcher");
var _index_patterns_service = require("./index_patterns_service");
var _routes = require("./routes");

==> opensearch-dashboards-3.3.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/data/server/index_patterns/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  IndexPatternsFetcher: true,
  FieldDescriptor: true,
  shouldReadFieldFromDocValues: true,
  IndexPatternsService: true,
  IndexPatternsServiceStart: true
};
Object.defineProperty(exports, "FieldDescriptor", {
  enumerable: true,
  get: function () {
    return _fetcher.FieldDescriptor;
  }
});
Object.defineProperty(exports, "IndexPatternsFetcher", {
  enumerable: true,
  get: function () {
    return _fetcher.IndexPatternsFetcher;
  }
});
Object.defineProperty(exports, "IndexPatternsService", {
  enumerable: true,
  get: function () {
    return _index_patterns_service.IndexPatternsService;
  }
});
Object.defineProperty(exports, "IndexPatternsServiceStart", {
  enumerable: true,
  get: function () {
    return _index_patterns_service.IndexPatternsServiceStart;
  }
});
Object.defineProperty(exports, "shouldReadFieldFromDocValues", {
  enumerable: true,
  get: function () {
    return _fetcher.shouldReadFieldFromDocValues;
  }
});
var _utils = require("./utils");
Object.keys(_utils).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _utils[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _utils[key];
    }
  });
});
var _fetcher = require("./fetcher");
var _index_patterns_service = require("./index_patterns_service");
